xkcd: Legal Hacks

- Archive
- What If?
- Blag
- Store
- About

A webcomic of romance,
sarcasm, math, and language.
Preorder: Amazon, Barnes & Noble, Indie Bound, Hudson
In other news, Space Weird Thing is delightful, and I feel surprisingly invested in @xkcdbracket's results.
Legal Hacks

- |<
- < Prev
- Random
- Next >
- >|

- |<
- < Prev
- Random
- Next >
- >|

Permanent link to this comic: http://xkcd.com/504/
Image URL (for hotlinking/embedding): http://imgs.xkcd.com/comics/legal_hacks.png
[[A woman sits at her computer, a man standing behind her. The woman speaks first.]] Woman: Another ISP's filtering content. Man: Thank God for Crypto. [[The man stands alone; the woman is presumably off-panel left.]] Man: It wasn't that long ago that RSA was illegal to export. Classified a munition. [[The woman, sitting in her chair, is looking back towards the man, presumably off-panel right.]] Woman: You know, I think the crypto community took the wrong side in that fight. We should've lobbied to keep it counted as a weapon. Man: Why? [[She is now turned around in the chair looking at the man, who is in-panel again.]] Woman: Once they get complacent, we break out the second amendment. [[The man has his hand on his chin, contemplatively.]] Man: ...Damn. {{Title text: It's totally a reasonable modern analogue. Jefferson would have been all about crypto.}}
RSS Feed - Atom Feed
Comics I enjoy:
Three Word Phrase, SMBC, Dinosaur Comics, Oglaf (nsfw), A Softer World, Buttersafe, Perry Bible Fellowship, Questionable Content, Buttercup Festival, Homestuck, Junior Scientist Power Hour

Warning: this comic occasionally contains strong language (which may be unsuitable for children), unusual humor (which may be unsuitable for adults), and advanced mathematics (which may be unsuitable for liberal-arts majors).

BTC 1FhCLQK2ZXtCUQDtG98p6fVH7S6mxAsEey
We did not invent the algorithm. The algorithm consistently finds Jesus. The algorithm killed Jeeves.
The algorithm is banned in China. The algorithm is from Jersey. The algorithm constantly finds Jesus.
This is not the algorithm. This is close.

This work is licensed under a Creative Commons Attribution-NonCommercial 2.5 License.

This means you're free to copy and share these comics (but not to sell them). More details.